<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:strip-space elements="*"/>
	<xsl:output method="html" indent="yes" encoding="utf-8"/>

	<xsl:template match="VIEW-CONTENT">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="SEARCH-FORM">
		<fieldset>
			<legend><xsl:value-of select="@TITLE"/></legend>
			<div class="fieldset-block">
				<table width="100%" border="0" cellpadding="0" cellspacing="0">
					<tr>
						<td width="50%"><xsl:apply-templates select="CURRENT-CATEGORY"/></td>
						<td width="50%">
							<table cellpadding="0" cellspacing="0" border="0" align="right" class="control-title-near-input">
								<tr>
									<td class="title-block">
										<xsl:apply-templates select="CONTROL[@NAME='searchString']" mode="label">
											<xsl:with-param name="style">white-space: nowrap;</xsl:with-param>
										</xsl:apply-templates>
									</td>
									<td class="input-block">
										<xsl:apply-templates select="CONTROL[@NAME='searchString']" mode="fotoliaSearchForm"/>
									</td>
									<td class="description-block" style="padding-top: 3px;">
										<xsl:call-template name="BUTTON-CONTROL">
											<xsl:with-param name="title" select="SEARCH-BUTTON/@TITLE"/>
											<xsl:with-param name="action">self.parent.fotoliaSearchFormManager.searchForm.setPageNum(1); self.parent.fotoliaSearchFormManager.search();</xsl:with-param>
										</xsl:call-template>
									</td>
								</tr>
							</table>
						</td>
					</tr>
				</table>
				<xsl:apply-templates select="CHILD-LIST"/>
			</div>
		</fieldset>
		<script type="text/javascript" language="javascript">
			initSearchForm();
			<xsl:apply-templates select="CURRENT-CATEGORY" mode="init"/>
			<xsl:apply-templates select="CHILD-LIST" mode="init"/>
		</script>
	</xsl:template>

	<xsl:template match="SEARCH-FORM/CONTROL[@NAME='searchString']" mode="fotoliaSearchForm">
		<xsl:choose>
			<xsl:when test="@DEFAULT-VALUE">
				<xsl:apply-templates select="current()" mode="control">
					<xsl:with-param name="class">sb-input sb-text-light</xsl:with-param>
					<xsl:with-param name="size">60</xsl:with-param>
					<xsl:with-param name="value" select="@DEFAULT-VALUE"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="current()" mode="control">
					<xsl:with-param name="size">60</xsl:with-param>
				</xsl:apply-templates>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="CURRENT-CATEGORY">
		<span><xsl:value-of select="@TITLE"/>: </span><xsl:apply-templates select="CATEGORY"/>
	</xsl:template>

	<xsl:template match="CURRENT-CATEGORY/CHILD-LIST">
		<table width="100%" border="0" cellpadding="0" cellspacing="0">
			<tr height="1px">
				<td style="padding: 10px 0px 10px 0px;">
					<div style="height: 1px; background-color: #ccc;"><span></span></div>
				</td>
			</tr>
			<tr>
				<td>
					<table width="100%" border="0" cellpadding="0" cellspacing="0">
						<tr>
							<td valign="top" style="padding: 0px 10px 10px 0px; width: 1%;">
								<xsl:value-of select="@TITLE"/>:
							</td>
							<td valign="top">
								<xsl:apply-templates select="CATEGORY"/>
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="CURRENT-CATEGORY/CATEGORY">
		<xsl:choose>
			<xsl:when test="position() = last()">
				<span id="Fotolia_{@TYPE}_category_{@ID}"><xsl:value-of select="@TITLE"/></span>
			</xsl:when>
			<xsl:otherwise>
				<a id="Fotolia_{@TYPE}_category_{@ID}" href="#" style="white-space: nowrap;"><xsl:value-of select="@TITLE"/></a><span> > </span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="CHILD-LIST/CATEGORY">
		<a id="Fotolia_{@TYPE}_category_{@ID}" class="sb-fotolia-link" href="#" style="white-space: nowrap;"><xsl:value-of select="@TITLE"/></a>
		<xsl:if test="position() != last()">
			<span> | </span>
		</xsl:if>
	</xsl:template>

	<xsl:template match="CURRENT-CATEGORY|CHILD-LIST" mode="init">
		<xsl:apply-templates select="CATEGORY" mode="init"/>
	</xsl:template>

	<xsl:template match="CURRENT-CATEGORY/CATEGORY" mode="init">
		<xsl:choose>
			<xsl:when test="position() = last()">
				self.parent.fotoliaSearchFormManager.setCurrentCategory(InitCategory('<xsl:value-of select="@TYPE"/>', '<xsl:value-of select="@ID"/>', '<xsl:value-of select="@JS-SAFE-TITLE"/>', '<xsl:value-of select="@PARENT-ID"/>'));
			</xsl:when>
			<xsl:otherwise>
				InitCategory('<xsl:value-of select="@TYPE"/>', '<xsl:value-of select="@ID"/>', '<xsl:value-of select="@JS-SAFE-TITLE"/>', '<xsl:value-of select="@PARENT-ID"/>');
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="CHILD-LIST/CATEGORY" mode="init">
		InitCategory('<xsl:value-of select="@TYPE"/>', '<xsl:value-of select="@ID"/>', '<xsl:value-of select="@JS-SAFE-TITLE"/>', '<xsl:value-of select="@PARENT-ID"/>');
	</xsl:template>

</xsl:stylesheet>